/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.mailreaderjpa;

import java.io.Serializable;
import java.sql.Timestamp;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Version;

/**
 * <p>JPA entity class for the <code>MAILREADER_PROTOCOLS</code> table.</p>
 */
@Entity(name="mailreader_protocols")
@NamedQueries({
    @NamedQuery(name="Protocol.findAll", query="SELECT p FROM mailreader_protocols p")
})
public class Protocol implements Serializable {

    @Id
    @Column(name="protocol_id")
    @GeneratedValue(strategy = GenerationType.AUTO)
    private Integer id;
    
    /** Creates a new instance of Protocol */
    public Protocol() {
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public int hashCode() {
        if (getId() != null) {
            return getId().intValue();
        } else {
            return super.hashCode();
        }
    }

    public boolean equals(Object obj) {
        if ((obj instanceof Protocol)
            && (getId() != null)) {
            return getId().equals(((Protocol) obj).getId());
        } else {
            return false;
        }
    }

    public String toString() {
        return "org.apache.mailreaderjpa.Protocol[id=" + id + "]";
    }
    
    @Column(nullable=false)
    private String description;
    @Column(name="last_update")
    @Version()
    private Timestamp lastUpdate;

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Timestamp getLastUpdate() {
        return lastUpdate;
    }

    public void setLastUpdate(Timestamp lastUpdate) {
        this.lastUpdate = lastUpdate;
    }

}
